@@ -20,16 +20,14 @@
 
 *****************************************************************************/
 
+#include "qsynthAbout.h"
+#include "qsynthChannels.h"
+
 #include <qvalidator.h>
 #include <qmessagebox.h>
 #include <qpopupmenu.h>
 #include <qfileinfo.h>
 
-#include "config.h"
-
-#include "qsynthChannels.h"
-#include "qsynthAbout.h"
-
 
 // Kind of constructor.
 void qsynthChannelsForm::init (void)
@@ -41,7 +39,7 @@ void qsynthChannelsForm::init (void)
     m_pOptions = NULL;
     m_pEngine  = NULL;
     m_pSynth   = NULL;
-    
+
     // Initialize dirty control state.
     m_iDirtySetup = 0;
     m_iDirtyCount = 0;
@@ -98,7 +96,7 @@ void qsynthChannelsForm::setup ( qsynthOptions *pOptions, qsynthEngine *pEngine,
     m_pOptions = pOptions;
     m_pEngine  = pEngine;
     m_pSynth   = pEngine ? pEngine->pSynth : NULL;
-        
+
     // Update caption.
     QString sCaption = QSYNTH_TITLE ": " + tr("Channels");
     if (pEngine)
@@ -111,7 +109,7 @@ void qsynthChannelsForm::setup ( qsynthOptions *pOptions, qsynthEngine *pEngine,
         m_ppChannels = NULL;
         m_iChannels  = 0;
     }
-    
+
     // Allocate a new channel list view...
     ChannelsListView->clear();
     if (m_pSynth && m_ppChannels == NULL) {
@@ -211,21 +209,24 @@ void qsynthChannelsForm::setChannelOn ( int iChan, bool bOn )
 // Channel view context menu handler.
 void qsynthChannelsForm::contextMenu( QListViewItem *pItem, const QPoint& pos, int )
 {
-    int iItemID;
+	int iItemID;
 
-    // Build the channel context menu...
-    QPopupMenu* pContextMenu = new QPopupMenu(this);
+	// Build the channel context menu...
+	QPopupMenu* pContextMenu = new QPopupMenu(this);
 
-    bool bEnabled = (m_pSynth && pItem);
-    iItemID = pContextMenu->insertItem(tr("Edit") + "...", this, SLOT(editSelectedChannel()));
-    pContextMenu->setItemEnabled(iItemID, bEnabled);
-    pContextMenu->insertSeparator();
-    iItemID = pContextMenu->insertItem(tr("Refresh"), this, SLOT(updateAllChannels()));
-    pContextMenu->setItemEnabled(iItemID, bEnabled);
+	bool bEnabled = (m_pSynth && pItem);
+	iItemID = pContextMenu->insertItem(
+		QIconSet(QPixmap::fromMimeSource("edit1.png")),
+		tr("Edit") + "...", this, SLOT(editSelectedChannel()));
+	pContextMenu->setItemEnabled(iItemID, bEnabled);
+	pContextMenu->insertSeparator();
+	iItemID = pContextMenu->insertItem(
+		tr("Refresh"), this, SLOT(updateAllChannels()));
+	pContextMenu->setItemEnabled(iItemID, bEnabled);
 
-    pContextMenu->exec(pos);
-    
-    delete pContextMenu;
+	pContextMenu->exec(pos);
+
+	delete pContextMenu;
 }
 
 
@@ -322,7 +323,8 @@ void qsynthChannelsForm::deletePreset (void)
         return;
 
     // Try to prompt user if he/she really wants this...
-    if (QMessageBox::warning(this, tr("Warning"),
+    if (QMessageBox::warning(this,
+		QSYNTH_TITLE ": " + tr("Warning"),
         tr("Delete preset:") + "\n\n" +
         sPreset + "\n\n" +
         tr("Are you sure?"),
