@@ -20,6 +20,8 @@
 
 *****************************************************************************/
 
+#include "qsynthAbout.h"
+
 #include <qapplication.h>
 #include <qeventloop.h>
 #include <qmessagebox.h>
@@ -30,14 +32,10 @@
 
 #include <math.h>
 
-#include "config.h"
-
 #ifdef HAVE_SIGNAL_H
 #include <signal.h>
 #endif
 
-#include "qsynthAbout.h"
-
 // Timer constant stuff.
 #define QSYNTH_TIMER_MSECS  100
 #define QSYNTH_DELAY_MSECS  200
@@ -68,10 +66,10 @@ static fluid_cmd_handler_t* qsynth_newclient ( void* data, char* )
 
 int qsynth_process ( void *pvData, int len, int nin, float **in, int nout, float **out )
 {
-    qsynthEngine *pEngine = (qsynthEngine *) pvData;
+	qsynthEngine *pEngine = (qsynthEngine *) pvData;
 	// Call the synthesizer process function to fill
 	// the output buffers with its audio output.
-    if (::fluid_synth_process(pEngine->pSynth, len, nin, in, nout, out) != 0)
+	if (::fluid_synth_process(pEngine->pSynth, len, nin, in, nout, out) != 0)
 		return -1;
 	// Now find the peak level for this buffer run...
 	if (pEngine == g_pCurrentEngine) {
@@ -87,7 +85,7 @@ int qsynth_process ( void *pvData, int len, int nin, float **in, int nout, float
 	// Surely a success :)
 	return 0;
 }
- 
+
 //-------------------------------------------------------------------------
 // Midi router stubs to have some midi activity feedback.
 
@@ -353,7 +351,8 @@ bool qsynthMainForm::queryClose (void)
                 if (pTab) {
                     qsynthEngine *pEngine = pTab->engine();
                     if (pEngine && pEngine->pSynth) {
-                        bQueryClose = (QMessageBox::warning(this, tr("Warning"),
+                        bQueryClose = (QMessageBox::warning(this,
+							QSYNTH_TITLE ": " + tr("Warning"),
                             QSYNTH_TITLE " " + tr("is about to terminate.") + "\n\n" +
                             tr("Are you sure?"),
                             tr("OK"), tr("Cancel")) == 0);
@@ -558,7 +557,8 @@ void qsynthMainForm::appendMessagesError( const QString& s )
 
     appendMessagesColor(s.simplifyWhiteSpace(), "#ff0000");
 
-    QMessageBox::critical(this, tr("Error"), s, tr("Cancel"));
+    QMessageBox::critical(this,
+		QSYNTH_TITLE ": " + tr("Error"), s, tr("Cancel"));
 }
 
 
@@ -586,7 +586,7 @@ void qsynthMainForm::updateMessagesLimit (void)
         if (m_pOptions->bMessagesLimit)
             m_pMessagesForm->setMessagesLimit(m_pOptions->iMessagesLimitLines);
         else
-            m_pMessagesForm->setMessagesLimit(0);
+            m_pMessagesForm->setMessagesLimit(-1);
     }
 }
 
@@ -601,7 +601,7 @@ void qsynthMainForm::updateOutputMeters (void)
         OutputGroupBox->show();
     else
         OutputGroupBox->hide();
-        
+
     adjustSize();
 }
 
@@ -684,12 +684,12 @@ void qsynthMainForm::systemTrayContextMenu ( const QPoint& pos )
         qsynthTab *pTab = (qsynthTab *) TabBar->tabAt(iTab);
         if (pTab) {
             pEngine = pTab->engine();
-            if (pEngine) {
-        		iItemID = m_pEnginesMenu->insertItem(pEngine->name());
-        		m_pEnginesMenu->setItemChecked(iItemID, pEngine == currentEngine());
-        		m_pEnginesMenu->setItemParameter(iItemID, iTab);
+			if (pEngine) {
+				iItemID = m_pEnginesMenu->insertItem(pEngine->name());
+				m_pEnginesMenu->setItemChecked(iItemID, pEngine == currentEngine());
+				m_pEnginesMenu->setItemParameter(iItemID, iTab);
 			}
-        }
+		}
     }
     QObject::connect(m_pEnginesMenu, SIGNAL(activated(int)), this, SLOT(activateEnginesMenu(int)));
     // Add presets menu to the main context menu...
@@ -770,6 +770,8 @@ void qsynthMainForm::stabilizeForm (void)
     }
     RestartPushButton->setEnabled(true);
 
+	DeleteEnginePushButton->setEnabled(bEnabled && !pEngine->isDefault());
+
     MessagesPushButton->setOn(m_pMessagesForm && m_pMessagesForm->isVisible());
     ChannelsPushButton->setOn(m_pChannelsForm && m_pChannelsForm->isVisible());
 }
@@ -876,12 +878,13 @@ bool qsynthMainForm::deleteEngineTab ( qsynthEngine *pEngine, qsynthTab *pTab )
         return false;
 
     // Try to prompt user if he/she really wants this...
-    bool bResult = (QMessageBox::warning(this, tr("Warning"),
+    bool bResult = (QMessageBox::warning(this,
+		QSYNTH_TITLE ": " + tr("Warning"),
         tr("Delete fluidsynth engine:") + "\n\n" +
         pEngine->name() + "\n\n" +
         tr("Are you sure?"),
         tr("OK"), tr("Cancel")) == 0);
-    
+
     if (bResult) {
         // First we try to stop the angine.
         stopEngine(pEngine);
@@ -1033,7 +1036,8 @@ void qsynthMainForm::showOptionsForm (void)
                 (!bStdoutCapture &&  m_pOptions->bStdoutCapture) ||
                 ( bKeepOnTop     && !m_pOptions->bKeepOnTop)     ||
                 (!bKeepOnTop     &&  m_pOptions->bKeepOnTop)) {
-                QMessageBox::information(this, tr("Information"),
+                QMessageBox::information(this,
+					QSYNTH_TITLE ": " + tr("Information"),
                     tr("Some settings will be only effective\n"
                        "next time you start this program."), tr("OK"));
             }
@@ -1161,12 +1165,12 @@ void qsynthMainForm::timerSlot (void)
                     pEngine->iMidiState++;
                     pTab->setOn(true);
                     iTabUpdate++;
-                    // Change the system tray icon background color!
-                    if (m_pSystemTray && m_iSystemTrayState == 0) {
-                        m_iSystemTrayState++;
-				        m_pSystemTray->setBackgroundMode(Qt::PaletteBackground);
-				        m_pSystemTray->setPaletteBackgroundColor(Qt::green);
-				        m_pSystemTray->repaint(true);
+					// Change the system tray icon background color!
+					if (m_pSystemTray && m_iSystemTrayState == 0) {
+						m_iSystemTrayState++;
+						m_pSystemTray->setBackgroundMode(Qt::PaletteBackground);
+						m_pSystemTray->setPaletteBackgroundColor(Qt::green);
+						m_pSystemTray->repaint(true);
 					}
                 }
             }
@@ -1175,10 +1179,10 @@ void qsynthMainForm::timerSlot (void)
                 pTab->setOn(false);
                 iTabUpdate++;
                 // Reset the system tray icon background!
-                if (m_pSystemTray && m_iSystemTrayState > 0) {
-                    m_iSystemTrayState--;
-			        m_pSystemTray->setBackgroundMode(Qt::X11ParentRelative);
-			        m_pSystemTray->repaint(true);
+				if (m_pSystemTray && m_iSystemTrayState > 0) {
+					m_iSystemTrayState--;
+					m_pSystemTray->setBackgroundMode(Qt::X11ParentRelative);
+					m_pSystemTray->repaint(true);
 				}
             }
         }
@@ -1470,7 +1474,8 @@ void qsynthMainForm::stopEngine ( qsynthEngine *pEngine )
 void qsynthMainForm::restartAllEngines (void)
 {
     // Always prompt user...
-    bool  bRestart = (QMessageBox::warning(this, tr("Warning"),
+    bool  bRestart = (QMessageBox::warning(this,
+			QSYNTH_TITLE ": " + tr("Warning"),
             tr("New settings will be effective after\n"
                "restarting all fluidsynth engines.") + "\n\n" +
             tr("Please note that this operation may cause\n"
@@ -1486,6 +1491,8 @@ void qsynthMainForm::restartAllEngines (void)
             if (pTab)
                 stopEngine(pTab->engine());
         }
+		// Must make this one grayed out for a while...
+		RestartPushButton->setEnabled(false);
         // And making room for immediate restart...
         m_iTimerDelay = 0;
     }
@@ -1496,10 +1503,11 @@ void qsynthMainForm::restartAllEngines (void)
 void qsynthMainForm::restartEngine ( qsynthEngine *pEngine )
 {
     bool bRestart = true;
-    
+
     // If currently running, prompt user...
     if (pEngine && pEngine->pSynth) {
-        bRestart = (QMessageBox::warning(this, tr("Warning"),
+        bRestart = (QMessageBox::warning(this,
+			QSYNTH_TITLE ": " + tr("Warning"),
             tr("New settings will be effective after\n"
                "restarting the fluidsynth engine:") + "\n\n" +
             pEngine->name() + "\n\n" +
@@ -1513,6 +1521,9 @@ void qsynthMainForm::restartEngine ( qsynthEngine *pEngine )
     if (bRestart) {
         // Restarting means stopping current engine...
         stopEngine(pEngine);
+		// Must make current one grayed out for a while...
+		if (pEngine == currentEngine())
+			RestartPushButton->setEnabled(false);
         // And making room for immediate restart...
         m_iTimerDelay = 0;
     }
